"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureFlagActionProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const lodash_1 = require("lodash");
const loopback4_authentication_1 = require("loopback4-authentication");
const keys_1 = require("../keys");
const rest_1 = require("@loopback/rest");
let FeatureFlagActionProvider = class FeatureFlagActionProvider {
    constructor(getMetadata, user) {
        this.getMetadata = getMetadata;
        this.user = user;
    }
    value() {
        return () => this.action();
    }
    async action() {
        var _a;
        const metadata = await this.getMetadata();
        if (metadata) {
            const featureToCheck = [metadata.featureKey];
            if (featureToCheck.length && featureToCheck[0] === '*') {
                return true; // skip the check and always return true
            }
            const disabledFeatures = (_a = this.user) === null || _a === void 0 ? void 0 : _a.disabledFeatures;
            if (!disabledFeatures) {
                throw new rest_1.HttpErrors.InternalServerError('List of disabled features not passed to user');
            }
            return (0, lodash_1.intersection)(featureToCheck, disabledFeatures).length <= 0;
        }
        else {
            return false; // need to pass metadata to decorator
        }
    }
};
FeatureFlagActionProvider = tslib_1.__decorate([
    tslib_1.__param(0, core_1.inject.getter(keys_1.StrategyBindings.METADATA)),
    tslib_1.__param(1, (0, core_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__metadata("design:paramtypes", [Function, Object])
], FeatureFlagActionProvider);
exports.FeatureFlagActionProvider = FeatureFlagActionProvider;
//# sourceMappingURL=feature-flag-action.provider.js.map